@@ -5,9 +5,10 @@ from labml.configs import BaseConfigs
 
 
 def store_l1_l2(name: str, tensor: torch.Tensor):
-    tracker.add(f"{name}.mean", tensor.mean())
-    tracker.add(f"{name}.l1", tensor.abs().mean())
-    tracker.add(f"{name}.l2", (tensor ** 2).mean().sqrt())
+    if tensor.is_floating_point():
+        tracker.add(f"{name}.mean", tensor.mean())
+        tracker.add(f"{name}.l1", tensor.abs().mean())
+        tracker.add(f"{name}.l2", (tensor ** 2).mean().sqrt())
 
 
 def store_model_indicators(model: torch.nn.Module, model_name: str = "model"):
@@ -16,7 +17,7 @@ def store_model_indicators(model: torch.nn.Module, model_name: str = "model"):
             with torch.no_grad():
                 store_l1_l2(f"param.{model_name}.{name}", param)
                 if param.grad is not None:
-                    store_l1_l2(f"param.{model_name}.{name}.grad", param.grad)
+                    store_l1_l2(f"grad.{model_name}.{name}", param.grad)
 
 
 def get_modules(configs: BaseConfigs):
